import os as _os
_base = _os.path.dirname(__file__)
for _entry in sorted(_os.listdir(_base)):
    _path = _os.path.join(_base, _entry)
    if _os.path.isdir(_path) and not _entry.startswith((".", "_")):
        __path__.append(_path)

"""
Optuna-based classifier optimization module.

This module provides modern, efficient classifier optimization using Optuna with
intelligent caching and pre-generation of activations for maximum performance.
"""

from .activation_generator import ActivationData, ActivationGenerator, GenerationConfig
from .classifier_cache import CacheConfig, CacheMetadata, ClassifierCache
from .optuna_classifier_optimizer import ClassifierOptimizationConfig, OptimizationResult, OptunaClassifierOptimizer

__all__ = [
    # Activation generation
    "ActivationGenerator",
    "GenerationConfig",
    "ActivationData",
    # Classifier caching
    "ClassifierCache",
    "CacheConfig",
    "CacheMetadata",
    # Optuna optimization
    "OptunaClassifierOptimizer",
    "ClassifierOptimizationConfig",
    "OptimizationResult",
]
