import os as _os
_base = _os.path.dirname(__file__)
for _entry in sorted(_os.listdir(_base)):
    _path = _os.path.join(_base, _entry)
    if _os.path.isdir(_path) and not _entry.startswith((".", "_")):
        __path__.append(_path)

"""
Steering optimization utilities.

This module provides metrics and utilities for steering optimization.
The main optimization logic is in wisent.core.cli.optimize_steering.
"""

from .metrics import (
    calculate_comprehensive_metrics,
    evaluate_benchmark_performance,
    evaluate_probe_performance,
    generate_performance_summary,
)

__all__ = [
    "calculate_comprehensive_metrics",
    "evaluate_benchmark_performance",
    "evaluate_probe_performance",
    "generate_performance_summary",
]
