import os as _os
_base = _os.path.dirname(__file__)
for _entry in sorted(_os.listdir(_base)):
    _path = _os.path.join(_base, _entry)
    if _os.path.isdir(_path) and not _entry.startswith((".", "_")):
        __path__.append(_path)

"""Non-text modality adapter implementations."""

from .audio import AudioAdapter
from .multimodal import MultimodalAdapter, MultimodalSteeringConfig
from .robotics import RoboticsAdapter, RoboticsSteeringConfig
from .video import VideoAdapter, VideoSteeringConfig

__all__ = [
    'AudioAdapter',
    'MultimodalAdapter',
    'MultimodalSteeringConfig',
    'RoboticsAdapter',
    'RoboticsSteeringConfig',
    'VideoAdapter',
    'VideoSteeringConfig',
]
